summaryrefslogtreecommitdiffstats
path: root/vcs/cvsservice/cvspart.h
diff options
context:
space:
mode:
Diffstat (limited to 'vcs/cvsservice/cvspart.h')
-rw-r--r--vcs/cvsservice/cvspart.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/vcs/cvsservice/cvspart.h b/vcs/cvsservice/cvspart.h
index 886d13b2..c6c4e2dd 100644
--- a/vcs/cvsservice/cvspart.h
+++ b/vcs/cvsservice/cvspart.h
@@ -43,15 +43,15 @@ class CvsServicePart : public KDevVersionControl
public:
//! Standard constructor.
- CvsServicePart( TQObject *tqparent, const char *name, const TQStringList & );
+ CvsServicePart( TQObject *parent, const char *name, const TQStringList & );
//! Destructor.
virtual ~CvsServicePart();
/**
* Returns the configuration widget (for properly configuring the project to
* use CVS), child of @p tqparent.
*/
- virtual TQWidget *newProjectWidget( TQWidget *tqparent );
+ virtual TQWidget *newProjectWidget( TQWidget *parent );
/**
* Setup a directory tree for use with CVS.
*/
@@ -43,15 +43,15 @@ class CvsServicePart : public KDevVersionControl
/**
* Returns the configuration widget (for properly configuring the project to
- * use CVS), child of @p tqparent.
+ * use CVS), child of @p parent.
*/